@@ -1,5 +1,5 @@
 # prime/prime-japnese.rb: Japanese module for PRIME.
-# $Id: prime-japanese.rb,v 1.6 2004/04/29 21:35:54 komatsu Exp $
+# $Id: prime-japanese.rb,v 1.7 2004/08/29 13:51:16 komatsu Exp $
 #
 # Copyright (C) 2004 Hiroyuki Komatsu <komatsu@taiyaki.org>
 #     All rights reserved.
@@ -36,11 +36,11 @@ module PrimeJapanese
       'ư::' => ['֤::', 'Ǿá֤ʤ::'],
       'ư' => ['Ը', 'Ը', 'Ը', 'Ը', 'ʹԸ', 
 	'йԸ', '޹Ը', 'Ը', 'Ը', '(Ԥ)',
-	'', 'ư', '()'],
+	'', 'ư', '()', '&̾'],
       '' => ['ʽ֤ˡ', 'ʽ֤ǡ', 'ʽ֤',
-                 'ʽ֤ȡ', 'ʽ֤Ρ', 'ʽ֤',
-                 '֤ϡ'],
-      '̾' => ['̾', '()&̾', 'ư&̾'],
+                 'ʽ֤ȡ', 
+	'ʽ֤Ρ', 'ʽ֤', '֤ϡ', '³֤ȡ'],
+      '̾' => ['̾', '()&̾', 'ư&̾', '&̾'],
     }
 
     @pos_alias_reverse = {}
@@ -57,11 +57,11 @@ module PrimeJapanese
     @pos_connection_table = {
       '' => [''],
       'Ƭ' => ['̾'],
-      '̾'   => ['', 'ư첽', '̾'],
+      '̾'   => ['', 'ư첽', '̾', 'ƻ', 'ư'],
 
-      '̾&̾'   => ['', 'ư첽'],
-      '̾'        => ['', 'ư첽'],
+      '̾&̾'   => ['̾', '', 'ư첽'],
       '̾'        => ['', 'ư첽'],
+      '̾'        => ['̾', '', 'ư첽'],
 
       ## FIXME: ϡֽߡפǤϤʤϢΡ
       ## FIXME: <komatsu@taiyaki.org> (2004-01-19)
@@ -72,7 +72,7 @@ module PrimeJapanese
       'ư::Ϣi' => ['ư'],
       '' => ['ƻ', 'ư', 'ư&̾', 'ư'],
       'ƻ::Ϣ'   => ['̾', '̾&̾', '̾', '̾'],
-      'ƻ::Ϣku' => ['ƻ'],
+      'ƻ::Ϣku' => ['ƻ', 'ư'],
       'ư::Ϣ' => ['̾', '̾&̾', '̾', '̾'],
       'ư' => ['̾', '̾&̾', '̾', '̾'],
       '֤::Ϣde' => ['ư'],
@@ -90,6 +90,8 @@ module PrimeJapanese
 #      "֤::\t̾" => 0.9,
 #      "Ǿá֤ʤ::\t̾" => 0.9,
       "\t"  => 0.9,
+      "̾&̾\t̾" => 0.99,
+      "̾\t̾" => 0.99,
       "̾&̾\t=" => 0.99,
       "̾\t="      => 0.99,
       "=\t̾"   => 0.99,
@@ -100,6 +102,14 @@ module PrimeJapanese
       "=\t̾" => 0.99,
       "=\t̾" => 0.99,
       "=ɤ\t̾" => 0.99,
+      "=\t()&̾"   => 0.99,
+      "=\t()&̾"   => 0.99,
+      "=\t()&̾"   => 0.99,
+      "=ɤ\t()&̾"   => 0.99,
+      "=\t()&̾" => 0.99,
+      "=\t()&̾" => 0.99,
+      "=\t()&̾" => 0.99,
+      "=ɤ\t()&̾" => 0.99,
     }
     @pos_connection_cost_default = 0.8
     @pos_connection_pos = {
@@ -109,9 +119,11 @@ module PrimeJapanese
       "\t" => '̾',
       "̾\t" => '̾',
       "̾\tư첽" => 'ư',
-      "̾&̾\t" => '̾',
+      "̾&̾\t̾" => '̾',
+      "̾&̾\t"   => '̾',
       "̾&̾\tư첽" => 'ư',
-      "̾\t" => '̾',
+      "̾\t̾" => '̾',
+      "̾\t"   => '̾',
       "̾\tư첽" => 'ư',
       "̾\t" => '̾',
       "̾\tư첽" => 'ư',
@@ -375,7 +387,7 @@ class PrimeTypeConv
         PRIME_ENV['typing_method'] == nil then
       if conversion =~ /[a-zA-Z]/ then
         return [string]
-      elsif string =~ /^[0-9+-][0-9,.+-]*/ then
+      elsif string =~ /^-?[0-9+][0-9,.+-]*/ then
         numeral = $&
         string = string[numeral.length..-1]
         (conversion, pending, node) = suikyo.convert_internal(string)
